==> gtrpy-1.3.tar.gz: gtrpy-1.3/docs/image_size_data.md <==
# Image Size Data

Storing the size of the images used in `gtrpy/res` directory.

## Main Page

    x0     -> (20, 200)
    x1     -> (20, 200)
    x2     -> (20, 200)
    x3     -> (20, 200)
    g0beta -> (30, 200)
    g1beta -> (30, 200)
    g2beta -> (30, 200)
    g3beta -> (30, 200)

## GR Tensors Tab

    metrictensor         -> (30, 200)
    inversemetrictensor  -> (30, 200)
    chrissymbol          -> (30, 200)
    riemanntensor        -> (42, 200)
    riccitensor          -> (34, 200)
    ricciscalar          -> (12, 200)
    einsteintensor       -> (34, 200)
    weyltensor           -> (48, 200)
    kretschmannscalar    -> (12, 200)
    tracelessriccitensor -> (34, 200)

## Fields Tab

    scalarfield    -> (15, 200)
    vectorfield_10 -> (25, 200)
    vectorfield_01 -> (25, 200)
    tensorfield_20 -> (34, 200)
    tensorfield_11 -> (25, 200)
    tensorfield_02 -> (32, 200)

## Fields

### Scalar Field

    LX0             -> (20, 200)
    LX1             -> (20, 200)
    LX2             -> (20, 200)
    LX3             -> (20, 200)
    cov_scalarfield -> (35, 200)
    LX_scalarfield  -> (35, 200)

### Vector Field

    vectorfield_10_0   -> (20, 200)
    vectorfield_10_1   -> (20, 200)
    vectorfield_10_2   -> (20, 200)
    vectorfield_10_3   -> (20, 200)
    cov_vectorfield_10 -> (55, 200)
    LX_vectorfield_10  -> (55, 200)
    killingvector      -> (90, 200)
    ===============================
    vectorfield_01_0   -> (20, 200)
    vectorfield_01_1   -> (20, 200)
    vectorfield_01_2   -> (20, 200)
    vectorfield_01_3   -> (20, 200)
    LX_vectorfield_01  -> (55, 200)
    cov_vectorfield_01 -> (55, 200)

### Tensor Field

    tensorfield_20_0   -> (20, 200)
    tensorfield_20_1   -> (20, 200)
    tensorfield_20_2   -> (20, 200)
    tensorfield_20_3   -> (20, 200)
    cov_tensorfield_20 -> (60, 200)
    LX_tensorfield_20  -> (60, 200)
    ====================================
    tensorfield_11_0   -> (17, 200)
    tensorfield_11_1   -> (17, 200)
    tensorfield_11_2   -> (17, 200)
    tensorfield_11_3   -> (17, 200)
    cov_tensorfield_11 -> (52, 200)
    LX_tensorfield_11  -> (52, 200)
    ====================================
    tensorfield_02_0   -> (22, 200)
    tensorfield_02_1   -> (22, 200)
    tensorfield_02_2   -> (22, 200)
    tensorfield_02_3   -> (22, 200)
    cov_tensorfield_02 -> (60, 200)
    LX_tensorfield_02  -> (60, 200)
    ====================================

## Extra

    e -> (8, 200)
    gamma -> (27, 200)

==> gtrpy-1.7.tar.gz: gtrpy-1.7/docs/image_size_data.md <==
# Image Size Data

Storing the size of the images, which are used in the `gtrpy/res` directory.

## Main Page

    x0     -> (20, 200)
    x1     -> (20, 200)
    x2     -> (20, 200)
    x3     -> (20, 200)
    g0beta -> (30, 200)
    g1beta -> (30, 200)
    g2beta -> (30, 200)
    g3beta -> (30, 200)

## GR Tensors Tab

    metrictensor         -> (30, 200)
    inversemetrictensor  -> (30, 200)
    chrissymbol          -> (30, 200)
    riemanntensor        -> (42, 200)
    riccitensor          -> (34, 200)
    ricciscalar          -> (12, 200)
    einsteintensor       -> (34, 200)
    weyltensor           -> (48, 200)
    kretschmannscalar    -> (12, 200)
    tracelessriccitensor -> (34, 200)

## Fields Tab

    scalarfield    -> (15, 200)
    vectorfield_10 -> (25, 200)
    vectorfield_01 -> (25, 200)
    tensorfield_20 -> (34, 200)
    tensorfield_11 -> (25, 200)
    tensorfield_02 -> (32, 200)

## Fields

### Scalar Field

    LX0             -> (20, 200)
    LX1             -> (20, 200)
    LX2             -> (20, 200)
    LX3             -> (20, 200)
    cov_scalarfield -> (35, 200)
    LX_scalarfield  -> (35, 200)

### Vector Field

    vectorfield_10_0   -> (20, 200)
    vectorfield_10_1   -> (20, 200)
    vectorfield_10_2   -> (20, 200)
    vectorfield_10_3   -> (20, 200)
    cov_vectorfield_10 -> (55, 200)
    LX_vectorfield_10  -> (55, 200)
    killingvector      -> (90, 200)
    ===============================
    vectorfield_01_0   -> (20, 200)
    vectorfield_01_1   -> (20, 200)
    vectorfield_01_2   -> (20, 200)
    vectorfield_01_3   -> (20, 200)
    LX_vectorfield_01  -> (55, 200)
    cov_vectorfield_01 -> (55, 200)

### Tensor Field

    tensorfield_20_0   -> (20, 200)
    tensorfield_20_1   -> (20, 200)
    tensorfield_20_2   -> (20, 200)
    tensorfield_20_3   -> (20, 200)
    cov_tensorfield_20 -> (60, 200)
    LX_tensorfield_20  -> (60, 200)
    ====================================
    tensorfield_11_0   -> (17, 200)
    tensorfield_11_1   -> (17, 200)
    tensorfield_11_2   -> (17, 200)
    tensorfield_11_3   -> (17, 200)
    cov_tensorfield_11 -> (52, 200)
    LX_tensorfield_11  -> (52, 200)
    ====================================
    tensorfield_02_0   -> (22, 200)
    tensorfield_02_1   -> (22, 200)
    tensorfield_02_2   -> (22, 200)
    tensorfield_02_3   -> (22, 200)
    cov_tensorfield_02 -> (60, 200)
    LX_tensorfield_02  -> (60, 200)
    ====================================

## Extra

    e -> (8, 200)
    gamma -> (27, 200)
